.. _ext:

dooku.ext
=========

One of the most popular and missed Python's features is a feature to work
with extensions (plugins) and Dooku, as usual, provides this feature.


ExtensionManager
----------------

.. autoclass:: dooku.ext.ExtensionManager
